scripts/patch_modpython.py

changeset 7960
e8fc383322f7
parent 7923
91e843545d9a
child 8314
e3642a6a1e71
diff -r 44e15eda6506 -r e8fc383322f7 scripts/patch_modpython.py
--- a/scripts/patch_modpython.py	Tue Jan 05 18:28:31 2021 +0100
+++ b/scripts/patch_modpython.py	Wed Jan 06 13:47:01 2021 +0100
@@ -2,10 +2,10 @@
 
 # Copyright (c) 2003 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 # This is a  script to patch mod_python for eric6.
 
 """
-Script to patch mod_python for usage with the eric6 IDE.
+Script to patch mod_python for usage with the eric IDE.
 """
 
 import sys
@@ -36,7 +36,7 @@
     print()
     print("This script patches the file apache.py of the Mod_python"
           " distribution")
-    print("so that it will work with the eric6 debugger instead of pdb.")
+    print("so that it will work with the eric debugger instead of pdb.")
     print("Please see mod_python.html for more details.")
     print()
 
@@ -109,7 +109,7 @@
             s.write('    """\n')
             s.write('    Initialize the debugger and set the script name to be'
                     ' reported \n')
-            s.write('    by the debugger. This is a patch for eric6.\n')
+            s.write('    by the debugger. This is a patch for eric.\n')
             s.write('    """\n')
             s.write('    if not pdb.initDebugger("standard"):\n')
             s.write('        raise ImportError("Could not initialize'
@@ -118,7 +118,7 @@
             s.write("\n")
     
     if ericFound:
-        print("Mod_python is already patched for eric6.")
+        print("Mod_python is already patched for eric.")
         os.remove(sn)
     else:
         try:
@@ -2,10 +2,10 @@
 # Copyright (c) 2003 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
-# This is a  script to patch mod_python for eric6.
+# This is a  script to patch mod_python for eric.
 
 """

eric ide

mercurial